//
// ETSI (European Telecommunications Standards Institute, referred to as ETSI)
// ARF - ETSI ISG Augmented Reality Framework (ISG ARF)
// (C) 2022
//
// Development "World Storage", data management, authoring tools
//
// Authors:
// - Sylvain Renault (Fraunhofer HHI)
// 
// Date: Feb. 2022
//

#define USING_OPENAPI_GENERATOR // alt. is Swagger

using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEditor;
using ETSI.ARF.WorldStorage.RESTful;

#if USING_OPENAPI_GENERATOR
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Model;
#else
using IO.Swagger.Api;
using IO.Swagger.Model;
#endif


namespace ETSI.ARF.WorldStorage.UI
{
    public class TrackableWindow : EditorWindow
    {
        [HideInInspector] public WorldStorageSettings worldStorageSettings;

        [SerializeField] public List<string> trackables = new List<string>();

        bool groupEnabled;

        string uid = System.Guid.Empty.ToString();
        string creatorUid = System.Guid.Empty.ToString();
        string type = "Unknow";
        string unit = "Unknow";
        Vector2Int dim;

        private Trackable currentTrackable;
        private Vector2 scrollPos;
        private Color ori;
        private GUIStyle gsTest;

        public static void ShowWindow(WorldStorageSettings ws)
        {
            TrackableWindow win = EditorWindow.GetWindow(typeof(TrackableWindow), false, WorldStorageWindow.winName) as TrackableWindow;
            win.worldStorageSettings = ws;
        }

        public TrackableWindow()
        {
            // init somne stuffs
            //currentTrackable = new Trackable();
        }

        void OnGUI()
        {
            ori = GUI.backgroundColor; // remember ori color

            gsTest = new GUIStyle("window");
            gsTest.normal.textColor = WorldStorageWindow.arfColors[0];
            gsTest.fontStyle = FontStyle.Bold;

            scrollPos = EditorGUILayout.BeginScrollView(scrollPos, GUILayout.ExpandWidth(true));
            WorldStorageWindow.DrawCopyright();

            DrawTrackableStuffs();// currentTrackable);

            EditorGUILayout.EndScrollView();

            if (GUILayout.Button("Close Window"))
            {
                Close();
            }
        }

        void DrawTrackableStuffs()// Trackable trackable)
        {
            GUILayout.BeginVertical("AR Trackable", gsTest);
            //
            GUILayout.Label("Server: " + worldStorageSettings.serverName, EditorStyles.whiteLargeLabel);
            GUILayout.Label("Creator UID: " + creatorUid, EditorStyles.miniLabel); // readonly
            EditorGUILayout.Space();

            //GUILayout.BeginHorizontal();
            uid = EditorGUILayout.TextField("UID (0 = new one)", uid);
            EditorGUILayout.Space();

            GUI.backgroundColor = WorldStorageWindow.arfColors[1];
            if (GUILayout.Button("Get Parameters"))
            {
                Trackable t = RESTfulTrackableRequest.GetTrackable(worldStorageSettings, uid);
                creatorUid = t.CreatorUID.ToString();
                type = t.GetType().ToString();
                unit = t.UnitSystem.ToString();
            }
            GUI.backgroundColor = ori;

            type = EditorGUILayout.TextField("Trackable Type", type);
            unit = EditorGUILayout.TextField("Unit System", unit);

            EditorGUILayout.Space(10);
            dim = EditorGUILayout.Vector2IntField("Dimension", dim);

            EditorGUILayout.Space();
            GUILayout.Button("Payload from Asset...");

            EditorGUILayout.Space();
            groupEnabled = EditorGUILayout.BeginToggleGroup("Optional Parameters:", groupEnabled);
            EditorGUILayout.IntField("Number of KeyValues", 0);
            EditorGUILayout.Space();
            EditorGUILayout.TextField("Key", "");
            EditorGUILayout.TextField("Value", "");
            EditorGUILayout.EndToggleGroup();
            //
            GUILayout.EndVertical();

            GUI.backgroundColor = WorldStorageWindow.arfColors[3];
            if (GUILayout.Button("Delete Trackable"))
            {
                Debug.Log("Deleting Trackable");
                RESTfulTrackableRequest.DeleteTrackable(worldStorageSettings, uid);
                uid = System.Guid.Empty.ToString();
                creatorUid = System.Guid.Empty.ToString();
                type = "";
                unit = "";
                WorldStorageWindow.WorldStorageWindowSingleton.UpdateList();
                WorldStorageWindow.WorldStorageWindowSingleton.Repaint();
            }
            GUI.backgroundColor = ori;

            GUI.backgroundColor = WorldStorageWindow.arfColors[2];
            if (GUILayout.Button("Create/Update Trackable"))
            {
                Debug.Log("PostAddTrackable");
                if (string.IsNullOrEmpty(uid) || uid == "0") uid = System.Guid.Empty.ToString();
                Trackable t = RESTfulTrackableRequest.TrackableFromStrings(uid, worldStorageSettings.creatorUID);
                RESTfulTrackableRequest.PostAddTrackable(worldStorageSettings, t);
                WorldStorageWindow.WorldStorageWindowSingleton.UpdateList();
                WorldStorageWindow.WorldStorageWindowSingleton.Repaint();

                uid = t.UID.ToString();
                type = t.GetType().ToString();
                unit = t.UnitSystem.ToString();
            }
            GUI.backgroundColor = WorldStorageWindow.arfColors[5];
            if (GUILayout.Button("Generate GameObject Component"))
            {
            }
                GUI.backgroundColor = ori;
        }

  
    }
}