//
// ETSI (European Telecommunications Standards Institute, referred to as ETSI)
// ARF - ETSI ISG Augmented Reality Framework (ISG ARF)
// (C) 2022
//
// Development "World Storage", data management, authoring tools
//
// Authors:
// - Sylvain Renault (Fraunhofer HHI)
// 
// Date: Feb. 2022
//

using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEditor;

namespace ETSI.ARF.WorldStorage.UI
{
    [CustomEditor(typeof(WorldStorageSettings))]
    public class WorldStorageSettingsEditor : Editor
    {
        WorldStorageSettings worldStorageSettings;
        WorldStorageWindow win;

        public void OnEnable()
        {
            worldStorageSettings = (WorldStorageSettings)target;
        }

        public override void OnInspectorGUI()
        {
            serializedObject.Update();

            Color ori = GUI.backgroundColor;

            GUILayout.Label("Copyright(c) 2022, ETSI - ARF");
            EditorGUILayout.Space();
            GUILayout.Label("Parameters:", EditorStyles.boldLabel);
            DrawDefaultInspector();
            EditorGUILayout.Space();

            // creator uid button
            //GUILayout.BeginHorizontal();
            //GUI.backgroundColor = WorldStorageWindow.arfColors[1];
            if (GUILayout.Button("Create New Creator UID"))
            {
                worldStorageSettings.creatorUID = System.Guid.NewGuid().ToString();
                if (win != null) win.worldStorageSettings.creatorUID = worldStorageSettings.creatorUID;
            }
            //GUI.backgroundColor = ori;
            //GUILayout.EndHorizontal();

            // open win button
            GUI.backgroundColor = WorldStorageWindow.arfColors[1];
            if (GUILayout.Button("Open World Storage Window..."))
            {
                Debug.Log("Open Main ARF Window");
                win = EditorWindow.GetWindow(typeof(WorldStorageWindow), false, "ETSI ARF - Authoring Editor") as WorldStorageWindow;
                win.worldStorageSettings = worldStorageSettings;
            }
            GUI.backgroundColor = ori;
        }
    }
}